@@ -22,7 +22,7 @@ use base qw/Net::DRI::DRD/;
 
 use Net::DRI::Util;
 
-our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -151,6 +151,10 @@ sub domain_renew        { Net::DRI::Exception->die(0,'DRD',4,'No domain renew av
 sub contact_check       { Net::DRI::Exception->die(0,'DRD',4,'No contact check available in .EU'); }
 sub contact_check_multi { Net::DRI::Exception->die(0,'DRD',4,'No contact check available in .EU'); }
 sub contact_transfer    { Net::DRI::Exception->die(0,'DRD',4,'No contact transfer available in .EU'); }
+sub message_retrieve    { Net::DRI::Exception->die(0,'DRD',4,'No poll features available in .EU'); }
+sub message_delete      { Net::DRI::Exception->die(0,'DRD',4,'No poll features available in .EU'); }
+sub message_waiting     { Net::DRI::Exception->die(0,'DRD',4,'No poll features available in .EU'); }
+sub message_count       { Net::DRI::Exception->die(0,'DRD',4,'No poll features available in .EU'); }
 
 #################################################################################################################
 1;
