@@ -1,6 +1,6 @@
 ## Domain Registry Interface, ICANN policy on reserved names
 ##
-## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -19,7 +19,7 @@ package Net::DRI::DRD::ICANN;
 
 use strict;
 
-our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.6 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,6 +63,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 
 ## See http://www.icann.org/tlds/agreements/verisign/registry-agmt-appk-net-org-16apr01.htm & same
+## Updated to http://www.icann.org/tlds/agreements/tel/appendix-6-07apr06.htm
 sub is_reserved_name
 {
  my $domain=shift;
@@ -72,7 +73,7 @@ sub is_reserved_name
  foreach my $d (@d)
  {
   ## A (ICANN+IANA reserved)
-  return 1 if ($d=~m/^(?:aso|dnso|icann|internic|pso|afrinic|apnic|arin|example|gtld-servers|iab|iana|iana-servers|iesg|ietf|irtf|istf|lacnic|latnic|rfc-editor|ripe|root-servers)$/io);
+  return 1 if ($d=~m/^(?:aso|dnso|gnso|icann|internic|ccnso|pso|afrinic|apnic|arin|example|gtld-servers|iab|iana|iana-servers|iesg|ietf|irtf|istf|lacnic|latnic|rfc-editor|ripe|root-servers)$/io);
 
   ## C (tagged domain names)
   return 1 if (length($d)>3 && (substr($d,2,2) eq '--'));
@@ -83,7 +84,11 @@ sub is_reserved_name
  ## B.2
  return 1 if (length($d[-2])==2);
  ## B.3
- return 1 if ($d[-2]=~m/^(?:aero|arpa|biz|com|coop|edu|gov|info|int|mil|museum|name|net|org|pro)$/io);
+ ## Restriction lifted in newer gTLD
+ unless ($d[0]=~m/^(?:travel|mobi|cat|tel)$/io)
+ {
+  return 1 if ($d[-2]=~m/^(?:aero|arpa|biz|com|coop|edu|gov|info|int|mil|museum|name|net|org|pro)$/io);
+ }
  ## D (reserved for Registry operations)
  return 1 if ($d[-2]=~m/^(?:nic|whois|www)$/io);
 
