@@ -1,8 +1,7 @@
 ## Domain Registry Interface, DNSBE Domain EPP extension commands
 ## (based on Registration_guidelines_v4_7_2-Part_4-epp.pdf)
 ##
-## Copyright (c) 2006-2010,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
-##           (c) 2013 Michael Holloway <michael@thedarkwinter.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -12,19 +11,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::DNSBE::Domain;
 
 use strict;
-use warnings;
-
-use Carp;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
+use Net::DRI::Protocol::EPP::Core::Domain;
 use Net::DRI::Data::Hosts;
-use Net::DRI::Protocol::EPP::Util;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -54,8 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
-          (c) 2013 Michael Holloway <michael@thedarkwinter.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -72,7 +72,7 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- my %tmp=(
+ my %tmp=( 
           create            => [ \&create, undef ],
           update            => [ \&update, undef ],
           info              => [ undef, \&info_parse ],
@@ -82,32 +82,47 @@ sub register_commands
           transferq_request => [ \&transferq_request, undef ],
           trade             => [ \&trade, undef ],
           reactivate        => [ \&reactivate, undef ],
-          request_authcode  => [ \&request_authcode, undef ],
          );
 
  return { 'domain' => \%tmp };
 }
 
+sub capabilities_add
+{
+ return { 'domain_update' => { 'nsgroup' => [ 'add','del']} };
+}
+
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ 
+ my @ns=@{$mes->ns->{dnsbe}};
+ return $mes->command_extension_register($tag,sprintf('xmlns:dnsbe="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+}
+
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  ## Registrant contact is mandatory (optional in EPP), already added in Core, we just verify here
  Net::DRI::Exception->die(0,'protocol/EPP',11,'Registrant contact is mandatory in domain_create')
-     unless (Net::DRI::Util::has_contact($rd) &&  $rd->{contact}->get('registrant')->srid());
+     unless (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{contact}) && UNIVERSAL::isa($rd->{contact},'Net::DRI::Data::ContactSet') 
+           && $rd->{contact}->get('registrant')->srid());
 
  return unless exists($rd->{nsgroup});
  my @n=add_nsgroup($rd->{nsgroup});
 
- $epp->message()->command_extension('dnsbe', ['ext', ['create', ['domain', @n]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnsbe:ext');
+ $mes->command_extension($eid,['dnsbe:create',['dnsbe:domain',@n]]);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  if (grep { ! /^(?:add|del)$/ } $todo->types('nsgroup'))
  {
@@ -122,8 +137,8 @@ sub update
  push @n,['dnsbe:add',add_nsgroup($nsgadd)] if $nsgadd;
  push @n,['dnsbe:rem',add_nsgroup($nsgdel)] if $nsgdel;
 
- $epp->message()->command_extension('dnsbe', ['ext', ['update', ['domain', @n]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnsbe:ext');
+ $mes->command_extension($eid,['dnsbe:update',['dnsbe:domain',@n]]);
 }
 
 ## This is not written in the PDF document, but it should probably be there, like for .EU
@@ -133,72 +148,74 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('dnsbe','infData');
+ my $infdata=$mes->get_content('infData',$mes->ns('dnsbe'),1);
  return unless $infdata;
 
  my @c;
- foreach my $el ($infdata->getChildrenByTagNameNS($mes->ns('dnsbe'),'nsgroup'))
+ foreach my $el ($infdata->getElementsByTagNameNS($mes->ns('dnsbe'),'nsgroup'))
  {
   push @c,Net::DRI::Data::Hosts->new()->name($el->getFirstChild()->getData());
  }
 
  $rinfo->{domain}->{$oname}->{nsgroup}=\@c;
- return;
 }
 
-sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub delete
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  return unless (exists($rd->{deleteDate}) && $rd->{deleteDate});
 
  Net::DRI::Util::check_isa($rd->{deleteDate},'DateTime');
 
- $epp->message()->command_extension('dnsbe', ['ext', ['delete', ['domain', ['deleteDate', $rd->{deleteDate}->set_time_zone('UTC')->strftime("%Y-%m-%dT%T.%NZ")]]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'dnsbe:ext');
+ my @n=('dnsbe:delete',['dnsbe:domain',['dnsbe:deleteDate',$rd->{deleteDate}->set_time_zone('UTC')->strftime("%Y-%m-%dT%T.%NZ")]]);
+ $mes->command_extension($eid,\@n);
 }
 
 sub transfer_request
 {
  my ($epp,$domain,$rd)=@_;
- my $mes = $epp->message();
+ my $mes=$epp->message();
 
- $mes->command_extension('dnsbe', ['ext', ['transfer', ['domain', add_transfer($epp, $mes, $domain, $rd)]]]);
- return;
+ my @n=add_transfer($epp,$mes,$domain,$rd);
+ my $eid=build_command_extension($mes,$epp,'dnsbe:ext');
+ $mes->command_extension($eid,['dnsbe:transfer',['dnsbe:domain',@n]]);
 }
 
 sub add_transfer
 {
  my ($epp,$mes,$domain,$rd)=@_;
 
- Net::DRI::Exception::usererr_insufficient_parameters('registrant and billing are mandatory') unless (Net::DRI::Util::has_contact($rd) && $rd->{contact}->has_type('registrant') && $rd->{contact}->has_type('billing'));
+ Net::DRI::Exception::usererr_insufficient_parameters('registrant and billing are mandatory') unless (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{contact}) && UNIVERSAL::isa($rd->{contact},'Net::DRI::Data::ContactSet') && $rd->{contact}->has_type('registrant') && $rd->{contact}->has_type('billing'));
 
  my $cs=$rd->{contact};
  my @n;
 
  my $creg=$cs->get('registrant');
- Net::DRI::Exception::usererr_invalid_parameters('registrant must be a contact object or #AUTO#') unless (Net::DRI::Util::isa_contact($creg,'Net::DRI::Data::Contact::BE') || (!ref($creg) && ($creg eq '#AUTO#')));
+ Net::DRI::Exception::usererr_invalid_parameters('registrant must be a contact object or #AUTO#') unless (UNIVERSAL::isa($creg,'Net::DRI::Data::Contact') || (!ref($creg) && ($creg eq '#AUTO#')));
  push @n,['dnsbe:registrant',ref($creg)? $creg->srid() : '#AUTO#' ];
 
  if (exists($rd->{trDate}))
  {
   Net::DRI::Util::check_isa($rd->{trDate},'DateTime');
-  push @n,['dnsbe:trDate',$rd->{trDate}->set_time_zone('UTC')->strftime('%Y-%m-%dT%T.%NZ')];
+  push @n,['dnsbe:trDate',$rd->{trDate}->set_time_zone('UTC')->strftime("%Y-%m-%dT%T.%NZ")];
  }
 
  my $cbill=$cs->get('billing');
- Net::DRI::Exception::usererr_invalid_parameters('billing must be a contact object') unless Net::DRI::Util::isa_contact($cbill,'Net::DRI::Data::Contact::BE');
+ Net::DRI::Exception::usererr_invalid_parameters('billing must be a contact object') unless UNIVERSAL::isa($cbill,'Net::DRI::Data::Contact');
  push @n,['dnsbe:billing',$cbill->srid()];
 
  push @n,add_contact('accmgr',$cs,1) if $cs->has_type('accmgr');
  push @n,add_contact('tech',$cs,9) if $cs->has_type('tech');
  push @n,add_contact('onsite',$cs,5) if $cs->has_type('onsite');
 
- if (Net::DRI::Util::has_ns($rd))
+ if (exists($rd->{ns}) && (UNIVERSAL::isa($rd->{ns},'Net::DRI::Data::Hosts')) && !$rd->{ns}->is_empty())
  {
-  my $n=Net::DRI::Protocol::EPP::Util::build_ns($epp,$rd->{ns},$domain,'dnsbe');
-  my @ns=$mes->nsattrs('domain');
-  push @$n,{'xmlns:domain'=>shift(@ns)};
+  my $n=Net::DRI::Protocol::EPP::Core::Domain::build_ns($epp,$rd->{ns},$domain,'dnsbe');
+  my @ns=@{$mes->ns->{domain}};
+  push @$n,{'xmlns:domain'=>$ns[0],'xsi:schemaLocation'=>sprintf('%s %s',@ns)};
   push @n,$n;
  }
 
@@ -210,7 +227,7 @@ sub add_nsgroup
 {
  my ($nsg)=@_;
  return unless (defined($nsg) && $nsg);
- my @a=grep { defined($_) && $_ && !ref($_) && Net::DRI::Util::xml_is_normalizedstring($_,1,100) } map { Net::DRI::Util::isa_hosts($_)? $_->name() : $_ } (ref($nsg) eq 'ARRAY')? @$nsg : ($nsg);
+ my @a=grep { defined($_) && Net::DRI::Util::xml_is_normalizedstring($_,1,100) } map { UNIVERSAL::isa($_,'Net::DRI::Data::Hosts')? $_->name() : $_ } (ref($nsg) eq 'ARRAY')? @$nsg : ($nsg);
  return map { ['dnsbe:nsgroup',$_] } grep {defined} @a[0..8];
 }
 
@@ -218,7 +235,7 @@ sub add_contact
 {
  my ($type,$cs,$max)=@_;
  $max--;
- my @r=grep { Net::DRI::Util::isa_contact($_,'Net::DRI::Data::Contact::BE') } ($cs->get($type));
+ my @r=grep { UNIVERSAL::isa($_,'Net::DRI::Data::Contact') } ($cs->get($type));
  return map { ['dnsbe:'.$type,$_->srid()] } grep {defined} @r[0..$max];
 }
 
@@ -226,56 +243,47 @@ sub undelete
 {
  my ($epp,$domain)=@_;
  my $mes=$epp->message();
- my @d=Net::DRI::Protocol::EPP::Util::domain_build_command($mes,'undelete',$domain);
+ my @d=Net::DRI::Protocol::EPP::Core::Domain::build_command($mes,'undelete',$domain);
  $mes->command_body(\@d);
- return;
 }
 
 sub transferq_request
 {
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
- my @d=Net::DRI::Protocol::EPP::Util::domain_build_command($mes,['transferq',{'op'=>'request'}],$domain);
+ my @d=Net::DRI::Protocol::EPP::Core::Domain::build_command($mes,'transferq',$domain);
+
+ if (Net::DRI::Protocol::EPP::Core::Domain::verify_rd($rd,'period'))
+ {
+  Net::DRI::Util::check_isa($rd->{period},'DateTime::Duration');
+  push @d,Net::DRI::Protocol::EPP::Core::Domain::build_period($rd->{period});
+ }
 
- Carp::croak('Key "period" should be key "duration"') if Net::DRI::Util::has_key($rd,'period');
- push @d,Net::DRI::Protocol::EPP::Util::build_period($rd->{period}) if Net::DRI::Util::has_duration($rd);
  $mes->command_body(\@d);
 
- $mes->command_extension('dnsbe', ['ext', ['transferq', ['domain', add_transfer($epp, $mes, $domain, $rd)]]]);
- return;
+ my @n=add_transfer($epp,$mes,$domain,$rd);
+ my $eid=build_command_extension($mes,$epp,'dnsbe:ext');
+ $mes->command_extension($eid,['dnsbe:transferq',['dnsbe:domain',@n]]);
 }
 
 sub trade
 {
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
- my @d=Net::DRI::Protocol::EPP::Util::domain_build_command($mes,['trade',{'op'=>'request'}],$domain);
+ my @d=Net::DRI::Protocol::EPP::Core::Domain::build_command($mes,'trade',$domain);
  $mes->command_body(\@d);
- $mes->command_extension('dnsbe', ['ext', ['trade', ['domain', add_transfer($epp, $mes, $domain, $rd)]]]);
 
- return;
+ my @n=add_transfer($epp,$mes,$domain,$rd);
+ my $eid=build_command_extension($mes,$epp,'dnsbe:ext');
+ $mes->command_extension($eid,['dnsbe:trade',['dnsbe:domain',@n]]);
 }
 
 sub reactivate
 {
  my ($epp,$domain)=@_;
  my $mes=$epp->message();
- my @d=Net::DRI::Protocol::EPP::Util::domain_build_command($mes,'reactivate',$domain);
+ my @d=Net::DRI::Protocol::EPP::Core::Domain::build_command($mes,'reactivate',$domain);
  $mes->command_body(\@d);
- return;
-}
-
-sub request_authcode
-{
- my ($epp,$domain,$rd)=@_;
- my $mes = $epp->message();
-
- my @d;
- push @d,['dnsbe:domainName',$domain];
- push @d,['dnsbe:url',$rd->{'url'}] if $rd->{'url'};
- $mes->command_extension('dnsbe', ['ext', ['command', ['requestAuthCode', @d], ['clTRID', $mes->cltrid()]]]);
- # missing TRID
- return;
 }
 
 ####################################################################################################
