@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .MOBI Domain EPP extension commands
 ##
-## Copyright (c) 2006-2008,2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,15 +10,18 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::MOBI::Domain;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
-use Net::DRI::Protocol::EPP::Extensions::Afilias::MaintainerUrl;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -48,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,33 +77,44 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
+sub capabilities_add
+{
+ return { 'domain_update' => { 'maintainer_url' => [ 'set' ]} };
+}
+
 ####################################################################################################
 
 sub add_maintainer_url
 {
- my ($epp,$tag,$d)=@_;
- $epp->message()->command_extension('mobi', [$tag, $d]);
- return;
+ my ($mes,$tag,$url)=@_;
+
+ my @ns=@{$mes->ns()->{'mobi'}};
+ my $eid=$mes->command_extension_register($tag,sprintf('xmlns:mobi="%s" xsi:schemaLocation="%s %s"',$ns[0],$ns[0],$ns[1]));
+ $mes->command_extension($eid,['mobi:maintainerUrl',$url]);
 }
 
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- my $d=Net::DRI::Protocol::EPP::Extensions::Afilias::MaintainerUrl::create($rd);
- return unless defined $d;
- add_maintainer_url($epp,'create',$d);
- return;
+ Net::DRI::Exception::usererr_insufficient_parameters('maintainer_url is mandatory') unless (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{maintainer_url}) && $rd->{maintainer_url});
+
+ add_maintainer_url($mes,'mobi:create',$rd->{maintainer_url});
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
- my $d=Net::DRI::Protocol::EPP::Extensions::Afilias::MaintainerUrl::update($todo);
- return unless defined $d;
- add_maintainer_url($epp,'update',$d);
- return;
+ if (grep { ! /^(?:set)$/ } $todo->types('maintainer_url'))
+ {
+  Net::DRI::Exception->die(0,'protocol/EPP',11,'Only maintainer_url set available for domain');
+ }
+
+ Net::DRI::Exception::usererr_insufficient_parameters('maintainer_url is mandatory') unless $todo->set('maintainer_url');
+ add_maintainer_url($mes,'mobi:update',$todo->set('maintainer_url'));
 }
 
 sub info_parse
@@ -109,12 +123,13 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('mobi','infData');
+ my $infdata=$mes->get_content('infData',$mes->ns('mobi'),1);
  return unless $infdata;
 
- my $c=Net::DRI::Protocol::EPP::Extensions::Afilias::MaintainerUrl::info_parse($mes->ns('mobi'),$infdata);
- $rinfo->{$otype}->{$oname}->{maintainer_url}=$c if defined $c;
- return;
+ my $c=$infdata->getElementsByTagNameNS($mes->ns('mobi'),'maintainerUrl');
+ return unless ($c && $c->size()==1);
+
+ $rinfo->{domain}->{$oname}->{maintainer_url}=$c->shift()->getFirstChild()->getData();
 }
 
 ####################################################################################################
