@@ -1,7 +1,7 @@
 ## Domain Registry Interface, Net::DRI::Protocol::EPP class for .SE
-## Contributed by Elias Sidenbladh and Ulrich Wisser from NIC SE
+## Contributed by Elias Sidenbladh from NIC SE
 ##
-## Copyright (c) 2006,2008-2011,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,20 +11,26 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::SE;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
+use Net::DRI::Data::Contact::SE;
+
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::SE - .SE EPP Extensions for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::SE - Net::DRI::Protocol::EPP class for .SE
 
 =head1 DESCRIPTION
 
@@ -48,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008-2011,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -62,15 +68,22 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
-    my ($self,$rp)=@_;
-    my $version=$self->version();
-    $self->ns({iis => 'urn:se:iis:xml:epp:iis-1.2'}); ## this will be updated if needed after server greeting
-    return;
-}
+    my $h=shift;
+    my $c=ref($h) || $h;
 
-sub default_extensions { return qw/SE::Extensions SecDNS/; }
+    my ($drd,$version,$extrah)=@_;
+    my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+    $e{'Net::DRI::Protocol::EPP::Extensions::SE::Extensions'}=1;
+    my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+    my $rfact=$self->factories();
+    $rfact->{contact}=sub { return Net::DRI::Data::Contact::SE->new(); };
+
+    bless($self,$c); ## rebless
+    return $self;
+}
 
 ####################################################################################################
 1;
