@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP RGP Poll (EPP-RGP-Poll-Mapping.pdf)
 ##
-## Copyright (c) 2006-2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::VeriSign::PollRGP;
 
 use strict;
-use warnings;
-use feature 'state';
 
+use Net::DRI::Protocol::EPP;
+use Net::DRI::Protocol::EPP::Core::Status;
 use Net::DRI::Util;
-use Net::DRI::Protocol::EPP::Util;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -49,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,6 +65,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 ####################################################################################################
 
 sub register_commands
@@ -73,15 +78,6 @@ sub register_commands
  return { 'message' => \%tmp };
 }
 
-sub setup
-{
- my ($class,$po,$version)=@_;
-
- state $ns = { 'rgp-poll' => 'http://www.verisign.com/epp/rgp-poll-1.0' };
- $po->ns($ns);
- return;
-}
-
 ####################################################################################################
 
 sub parse
@@ -90,27 +86,30 @@ sub parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_response('rgp-poll','pollData');
- return unless defined $infdata;
+ my $infdata=$mes->get_content('pollData','http://www.verisign.com/epp/rgp-poll-1.0',0);
+ return unless $infdata;
 
  my %w=(action => 'rgp_notification');
- foreach my $el (Net::DRI::Util::xml_list_children($infdata))
+ my $c=$infdata->getFirstChild();
+ while ($c)
  {
-  my ($name,$c)=@$el;
+  my $name=$c->localname() || $c->nodeName();
+  next unless $name;
+
   if ($name eq 'name')
   {
-   $oname=lc($c->textContent());
+   $oname=$c->getFirstChild()->getData();
   } elsif ($name eq 'rgpStatus')
   {
-   $w{status}=$po->create_local_object('status')->add(Net::DRI::Protocol::EPP::Util::parse_node_status($c));
+   $w{status}=Net::DRI::Protocol::EPP::Core::Status->new([Net::DRI::Protocol::EPP::parse_status($c)]);
   } elsif ($name=~m/^(reqDate|reportDueDate)$/)
   {
-   $w{Net::DRI::Util::remcam($name)}=$po->parse_iso8601($c->textContent());
+   $w{Net::DRI::Util::remcam($name)}=DateTime::Format::ISO8601->new()->parse_datetime($c->getFirstChild()->getData());
   }
+  $c=$c->getNextSibling();
  }
 
  $rinfo->{domain}->{$oname}=\%w;
- return;
 }
 
 ####################################################################################################
